;;; Polish_patch.el
;;; a quick patch for TeXLive 7 to support Polish in NT Emacs
;;; based on
;;; Initialisation file for (NT) Emacs to be used with
;;; "Selected Tools for Multilingual Text Processing" CD
;;; (cf. http://www.orient.uw.edu.pl/~zzi/publikacje/JSB-Bach01.pdf)
;;; version 0.93 Pluta for Emacs 21.1 
;;;
;;; developed by Janusz S. Bie
;;; Department of Applied Computer Science
;;; Institute for Oriental Studies
;;; Warsaw University


;;; Last change 30.04.2002

;; just in case :-)
(setq default-enable-multibyte-characters t)


(defvar w32 nil
  "This is MS Windows 95/98/NT/2000 system")

(when (eq window-system 'w32)
  (setq w32 t))


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Localisation and coding
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


;; Uncomment this if you want to cut and paste multilingual text
;; (set-selection-coding-system `emacs-mule)
;; Don't be confused by an alias:
;(set-clipboard-coding-system `emacs-mule)

;; Uncommentthe appropriate lines for the support of additional
;; Windows code pages
;; (codepage-setup `437)
;; (codepage-setup `850)
;; (codepage-setup `851)
(codepage-setup `852)
;; (codepage-setup `855)
;; (codepage-setup `857)
;; (codepage-setup `860)
;; (codepage-setup `861)
;; (codepage-setup `862)
;; (codepage-setup `863)
;; (codepage-setup `864)
;; (codepage-setup `865)
;; (codepage-setup `869)
;; (codepage-setup `775)
(codepage-setup `1250)
;;(codepage-setup `1251)
;not supported:
;(codepage-setup `1252)
;;(codepage-setup `1253)
;(codepage-setup `1254)
;(codepage-setup `1255)
;(codepage-setup `1256)
;;(codepage-setup `1257)
;; not supported?:
;(codepage-setup `1258)

;;; from language/european.el
;; Polish ISO 8859-2 environment.
;; Maintainer: Wlodek Bzyl <matwb@univ.gda.pl>
;; Keywords: multilingual, Polish

;; renamed by JSB
(set-language-info-alist
 "Polish-il2" '((charset . (ascii latin-iso8859-2))
	   (coding-system . (iso-8859-2))
	   (coding-priority . (iso-8859-2))
	   (input-method . "polish-slash")
	   (nonascii-translation . latin-iso8859-2)
	   (unibyte-syntax . "latin-2")
	   (unibyte-display . iso-8859-2)
	   (tutorial . "TUTORIAL.pl")
	   (sample-text . "Pjd, ki-e t chmurno w gb flaszy")
	   (documentation . t))
 '("European"))

; addded by JSB
(set-language-info-alist
 "Polish-wl2" '((charset . (ascii latin-iso8859-2))
	   (coding-system . (cp1250))
	   (coding-priority . (cp1250))
	   (input-method . "polish-slash")
	   (nonascii-translation . cp1250)
	   (unibyte-syntax . "latin-2")
	   (unibyte-display . iso-8859-2)
	   (tutorial . "TUTORIAL.pl")
	   (sample-text . "Pjd, ki-e t chmurno w gb flaszy")
	   (documentation . t))
 '("European"))


;;; setup for Polish

; il2 abbreviation used for ISO Latin-2 in TeX *.tcx tables,
; other extensions created by analogy (w- Windows, d - DOS)
(setq file-coding-system-alist
      (append 
       '(("\\.eml\\'" . emacs-mule)
	("\\.il2\\'" . latin-2)
	("\\.wl2\\'" . cp1250)
	("\\.dl2\\'" . cp852)
	)
       file-coding-system-alist))
; Don't confuse with auto-coding-alist, which is only for reading.

(when w32
(defun w32-adjust-keyboard-coding-system ()
  "adjust coding system to keyboard layout"
  (interactive)
  (if (or (when (equal (w32-get-keyboard-layout)
	  '(1045 . 1045))
          (message "polska klawiatura programisty"))
          (when (equal (w32-get-keyboard-layout)
          '(1045 . 61447))
          (message "polska klawiatura maszynistki")))
      (set-keyboard-coding-system 'cp1250)
    (set-keyboard-coding-system nil )
  ))

(w32-adjust-keyboard-coding-system)
(global-set-key [language-change] 'w32-adjust-keyboard-coding-system)

; tylko dla 20.x:?

;; (when (equal (w32-get-current-locale-id) 1045)
;; we load this file only when the condition is true

(setq file-name-coding-system 'cp1250)
(set-language-environment "Polish-wl2")

;)
)

;; convenience
(setq coding-system-history 
	  (append (list "cp1250" "cp852" "latin-2" "emacs-mule") 
		  coding-system-history))



;;; coding test:
;;; pjd, ki-e t chmurno w gb flaszy
;;; PJD, KI-E T CHMURNO W GB FLASZY
;;; Local Variables: ***
;;; coding:latin-2 ***
;;; End: ***

