;; site-start.el from CRI-Universite de Rennes 1
;;
;; ESC-G + N => goto line N
;; line number in modeline
;; AUC-TeX as LaTeX mode
;; Activate "Auto Fill" mode by default
;; activate html mode if .html suffix
;; text-mode as default mode
;;
;; Eric.Picheral@univ-rennes1.fr 02/08/95
;; 15/10/96: auctex modes
;; 07/04/97: html-helper
;; 05/01/99: ISO-Latin1 if emacs-version > 20.5
;; 26/01/00: syntax coloring with font-lock and latex-units
;; 29/02/00: open up files using dlgopen (standard windows dialog box)
;;           italics

;(setq debug-on-error t)

(setq w32-enable-synthetised-fonts t)    ; This must be done before font settings! (Emacs 20)
;;(set-face-font 'italic "-*-Courier New-normal-i-*-*-11-*-*-*-c-*-iso8859-1")
;;(set-face-font 'bold-italic "-*-Courier New-bold-i-*-*-11-*-*-*-c-*-iso8859-1")

;; goto line n
(global-set-key "\M-g" 'goto-line)

;;; comment by JSB
;;; I had to comment it out, because it forces unibyte mode on all buffers
;;; and I don't know how to undo it later
;;; Moreover, the current documentation says:
;;; Semi-obsolete way to toggle display of ISO 8859 European characters.

;; display ISO-Latin1 characters with accents
;(standard-display-european t)

;; switch to ISO-Latin-1 (emacs > 20.3)
; (if (and (eq emacs-major-version 20)
; 	  (> emacs-minor-version 3))
;      (set-language-environment "Latin-1"))


;;; support for Polish loaded only on Polish Windows
(when (equal (w32-get-current-locale-id) 1045)
  (load-library "Polish_patch"))

;; line number into modeline
(add-hook 'text-mode-hook '(lambda () (line-number-mode 1)))

;; 
(defmacro parent-directory (f)
  "Return safe parent directory of the directory given as argument."
  `(directory-file-name
    (file-name-directory
     (directory-file-name ,f))))

;;; Add subdirectories to load-path
(add-to-list 'load-path (concat (parent-directory (invocation-directory)) "/site-lisp/auctex"))
(add-to-list 'load-path (concat (parent-directory (invocation-directory)) "/site-lisp/ocaml"))

;; activate html-mode if .html suffix
;(autoload 'html-mode "auc-html" "HTML editing mode" t)
;(setq auto-mode-alist (cons '("\\.html\\'" . html-mode) auto-mode-alist))

;; enhanced html mode
(autoload 'html-helper-mode "html-helper-mode" "Yay HTML" t)
(setq auto-mode-alist (cons '("\\.html$" . html-helper-mode) auto-mode-alist))
(setq html-helper-build-new-buffer t)
(setq html-helper-use-expert-menu t)
(setq html-helper-do-write-file-hooks t)
(add-hook 'html-helper-load-hook
  (function (lambda () (load "tables.el"))))

;; html <=> iso-latin-1
(autoload 'iso-html-minor-mode
          "iso-html"
          "Translate HTML to ISO 8859/1 while visiting a file."
          t)

(setq html-mode-hook 
      (function (lambda () (interactive)
                  (iso-html-minor-mode 1)
                     ; and other initializations
                     ; ...
                  )))

;; autofill mode
(add-hook 'text-mode-hook 'turn-on-auto-fill)
(setq default-major-mode 'text-mode)

;============================================================
;;;  coloring syntax for LaTeX sources (and other languages)
;;;;;;;;;;;;;;;;;
(setq font-lock-maximum-decoration t)
(if window-system
    (progn
      (global-font-lock-mode t nil)
      (require 'font-latex))
)

;; AUC-TeX mode for LaTeX
(require 'tex-site)
(setq TeX-auto-save t)
(setq TeX-parse-self t)
(setq-default TeX-master nil)
(add-hook 'LaTeX-mode-hook '(lambda () (local-unset-key "\M-g")))
(add-hook 'LaTeX-mode-hook '(lambda () (local-set-key "\M-g" 'goto-line)))
(add-hook 'LaTeX-mode-hook '(lambda () (local-set-key "\C-cg" 'LaTeX-fill-region)))
(add-hook 'LaTeX-mode-hook 'turn-on-bib-cite)
(require 'tex-fptex)
(require 'func-doc)
(require 'latex-units)

;; Keymap

(global-set-key [f5] 'undo)
(global-set-key [f6] 'call-last-kbd-macro)

(set-frame-height (selected-frame) 31)

;;; Pas de message au demarrage

(setq inhibit-startup-message t)
(setq inhibit-startup-echo-area-message "tp6")

;; (auto-fill-mode t)

(auto-compression-mode t)

;;; Cursor position, line number

(defun what-char-and-line ()
  "Print info on cursor position, line the point is on,
 and the total number of lines in the buffer."
  (interactive)
  (let* ((char (following-char))
         (beg (point-min))
         (end (point-max))
         (pos (point))
         (total (buffer-size))
         (percent (if (> total 50000)
                      ;; Avoid overflow from multiplying by 100!
                      (/ (+ (/ total 200) (1- pos)) (max (/ total 100) 1))
                    (/ (+ (/ total 2) (* 100 (1- pos))) (max total 1))))
         (hscroll (if (= (window-hscroll) 0)
                      ""
                    (format " Hscroll=%d" (window-hscroll))))
         (col (current-column)))
    (if (= pos end)
        (if (or (/= beg 1) (/= end (1+ total)))
            (message "point=%d/%d(%d%%) <%d - %d>  col %d %s End of buffer. Last line %d."
                     pos total percent beg end col hscroll (count-lines 1 (point-max)))
          (message "point=%d/%d(%d%%)  col %d %s End of buffer. Last line %d."
                   pos total percent col hscroll (count-lines 1 (point-max))))
      (if (or (/= beg 1) (/= end (1+ total)))
          (message "Car= %s (0%o)  point=%d/%d(%d%%) <%d - %d>  col %d %s ligne %d/%d"
                   (single-key-description char) char pos total percent beg end col hscroll
                   (count-lines 1 (1+ (point))) (count-lines 1 (point-max)))
        (message "Car = %s (0%o)  point=%d/%d(%d%%)  col %d %s ligne %d/%d"
                 (single-key-description char) char pos total percent col hscroll
                 (count-lines 1 (1+ (point))) (count-lines 1 (point-max)))))))

(global-set-key "\C-c=" 'what-char-and-line)

;;; Postscript printing

   (setq ps-paper-type 'a4)
   (global-set-key [f22] 'ps-spool-buffer-with-faces)
   (global-set-key [(shift f22)] 'ps-spool-region-with-faces)
   (global-set-key [(control f22)] 'ps-despool)

;;; Use pc bindings
(require 'pc-mode)
(pc-bindings-mode)
(pc-selection-mode)

;;; Non-incremental forward search : bind to key "^C s"
(global-set-key "\C-cs" 'search-forward)

;;; Non-incremental backward search: bind to key "^C r"
(global-set-key "\C-cr" 'search-backward)

;;; Unconditional exact search and replace
(global-set-key "\C-c%" 'replace-string)

;;; Compare two buffers : bind to key "^C w"
(global-set-key "\C-cw" 'compare-windows)

;;; Find lines where some regular expression occurs : "^C o"
(global-set-key "\C-co" 'occur)

; Cursor shapes are defined in
; `/usr/include/X11/cursorfont.h'; 
; for example, the `target' cursor is number 128;
; the `top_left_arrow' cursor is number 132.
(let ((mpointer (x-get-resource "*mpointer"
                                "*emacs*mpointer")))
  ;; If you have not set your mouse pointer
  ;;     then sent it, otherwise leave as is:
  (if (eq mpointer nil)
      (setq mpointer "132")) ; top_left_arrow
  (setq x-pointer-shape (string-to-int mpointer))
  (set-mouse-color "red"))

;; Change the modeline
;;
(setq mode-line-system-identification  
  (substring (system-name) 0
             (string-match "\\..+" (system-name))))
(setq default-mode-line-format
      (list ""
            'mode-line-modified
            "<"
            'mode-line-system-identification
            "> "
            "%14b"
            " "
            'default-directory
            " "
            "%[(" 
            'mode-name 
            'minor-mode-alist 
            "%n" 
            'mode-line-process  
            ")%]--" 
             "L %l--"
	     "C %c--"
            '(-3 . "%P")
            "-%-"))
;; Start with new default.
(setq mode-line-format default-mode-line-format)

;; Paren mode
(load "paren")

;;;
;;; French users (and maybe others) can uncomment the following
;;;

;; 
;;(load "alt-key")
;;(alt-iso)

;;(autoload 'fracc-mode "ue-fracc")
;;(add-hook 'LaTeX-mode-hook '(lambda () (fracc-mode fracc-tex8-encoding)) )
;;(add-hook 'find-file-hooks
;;    '(lambda () (fracc-mode (fracc-select-default-encoding))) )

;;
;; Use standard Windows dialog box to open files
(load "dlgopen")

;;
;; Gnuserv
;;
;
; There are a couple of gnuserv.exe / gnuclient.exe programs
; in the NTEmacs\bin directory.
; The gnuserv.el file in this directory is partly compatible
; with these programs and provides the base functionality :
; editing files in emacs from the command line. The flags '-q' 
; and '-eval' for gnuclient are ok. 
;
; You need to move gnuserv.exe and gnuclient.exe to some place 
; on your PATH. Then restart uncomment the following lines (for
; subsequent emacs runs) and evaluate them manually (C-j at the end
; the expression) or restart emacs.
;
;(require 'gnuserv)
;(gnuserv-start)
